diff --git a/clmctest/monitoring/conftest.py b/clmctest/monitoring/conftest.py
index ad4d96b17c85d8bd8149f3adf84247156abcba9e..c351aa81c8e45bba10360fc3fdab9573168b44a8 100644
--- a/clmctest/monitoring/conftest.py
+++ b/clmctest/monitoring/conftest.py
@@ -40,7 +40,7 @@ def streaming_sim_params(streaming_sim_config):
 
 
 @pytest.fixture(params=[{'database': 'CLMCMetrics'}], scope='module')
-def get_db_client(streaming_sim_config, request):
+def influx_db(streaming_sim_config, request):
     """
     Creates an Influx DB client for the CLMC metrics database
 
diff --git a/clmctest/monitoring/test_simresults.py b/clmctest/monitoring/test_simresults.py
index 73d984a1a852ab988a782ce780b4b85d1993cfe6..f05c10226b5498aae4d738bb5c3cabf494545e49 100644
--- a/clmctest/monitoring/test_simresults.py
+++ b/clmctest/monitoring/test_simresults.py
@@ -25,13 +25,13 @@ class TestSimulation(object):
         ('SELECT count(*) FROM "CLMCMetrics"."autogen"."mpegdash_service_config" WHERE ipendpoint=\'adaptive_streaming_I1_apache2\'',
          {"time" : "1970-01-01T00:00:00Z", "count_avg_running" : 3602, "count_avg_starting" : 3602, "count_avg_stopped" : 3602, "count_avg_stopping" : 3602, "count_running" : 3602, "count_starting" : 3602, "count_stopped" : 3602, "count_stopping" : 3602}),
     ])
-    def test_simulation(self, query, expected_result, get_db_client, run_simulation_fixture):
+    def test_simulation(self, query, expected_result, influx_db, run_simulation_fixture):
         """
         This is the entry point of the test. This method will be found and executed when the module is ran using pytest
 
         :param query: the query to execute (value obtained from the pytest parameter decorator)
         :param expected_result: the result expected from executing the query (value obtained from the pytest parameter decorator)
         :param get_db_client the import db client fixture - imported from contest.py
         :param run_simulation_fixture: the imported fixture to use to generate the testing data - the return value of the fixture is not needed in this case
         """
 
@@ -40,7 +40,7 @@ class TestSimulation(object):
         print("\n")  # prints a blank line for formatting purposes
 
         # the raise_errors=False argument is given so that we could actually test that the DB didn't return any errors instead of raising an exception
-        query_result = get_db_client.query(query, raise_errors=False)
+        query_result = influx_db.query(query, raise_errors=False)
 
         # test the error attribute of the result is None, that is no error is returned from executing the DB query
         assert query_result.error is None, "An error was encountered while executing query {0}.".format(query)
@@ -25,13 +25,13 @@ class TestSimulation(object):
         :param query: the query to execute (value obtained from the pytest parameter decorator)
         :param expected_result: the result expected from executing the query (value obtained from the pytest parameter decorator)
-        :param get_db_client the import db client fixture - imported from contest.py
+        :param influx_db the import db client fixture - imported from contest.py
         :param run_simulation_fixture: the imported fixture to use to generate the testing data - the return value of the fixture is not needed in this case
         """